# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/btravel/externaldata/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/btravel/externaldata/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Btravel\\Externaldata\\": "packages/btravel/externaldata/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Btravel\Externaldata\Providers\ExternaldataServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Externaldata'  => Btravel\Externaldata\Facades\Externaldata::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Btravel\\ExternaldataTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Btravel\Externaldata\Providers\ExternaldataServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Btravel\Externaldata\Providers\ExternaldataServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Btravel\Externaldata\Providers\ExternaldataServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/externaldata/{modulename}

**User**

    http://path-to-route-folder/user/externaldata/{modulename}

**Public**

    http://path-to-route-folder/externaldatas


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/externaldata/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/externaldata/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/externaldata/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/externaldata/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/externaldata/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/externaldata/{modulename}/{slug}
    METHOD: GET