<?php

namespace Btravel\Externaldata\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Btravel\Externaldata\Http\Requests\ExternaldataRequest;
use Btravel\Externaldata\Interfaces\ExternaldataRepositoryInterface;
use Btravel\Externaldata\Models\Externaldata;
use Btravel\Externaldata\Forms\Externaldata as Form;

/**
 * APIController  class for externaldata.
 */
class ExternaldataAPIController extends BaseController
{

    /**
     * Initialize externaldata resource controller.
     *
     * @param type ExternaldataRepositoryInterface $externaldata
     *
     * @return null
     */
    public function __construct(ExternaldataRepositoryInterface $externaldata)
    {
        parent::__construct();
        $this->repository = $externaldata;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Externaldata\Repositories\Criteria\ExternaldataResourceCriteria::class);
    }

    /**
     * Display a list of externaldata.
     *
     * @return Response
     */
    public function index(ExternaldataRequest $request)
    {
        return $this->repository
            ->setPresenter(\Btravel\Externaldata\Repositories\Presenter\ExternaldataPresenter::class)
            ->paginate();
    }

    /**
     * Display externaldata.
     *
     * @param Request $request
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function show(ExternaldataRequest $request, Externaldata $externaldata)
    {
        return $externaldata->setPresenter(\Btravel\Externaldata\Repositories\Presenter\ExternaldataListPresenter::class);
        ;
    }

    /**
     * Create new externaldata.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ExternaldataRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('externaldata::externaldata.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('externaldata/externaldata/' . $externaldata->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('externaldata/externaldata');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the externaldata.
     *
     * @param Request $request
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function update(ExternaldataRequest $request, Externaldata $externaldata)
    {
        try {
            $data = $request->all();

            $externaldata->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('externaldata::externaldata.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('externaldata/externaldata/' . $externaldata->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('externaldata/externaldata/' . $externaldata->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the externaldata.
     *
     * @param Model   $externaldata
     *
     * @return Response
     */
    public function destroy(ExternaldataRequest $request, Externaldata $externaldata)
    {
        try {
            $externaldata->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('externaldata::externaldata.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('externaldata/externaldata/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('externaldata/externaldata/' . $externaldata->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
