<?php

namespace Btravel\Externaldata\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Externaldata\Models\Externaldata;

class ExternaldataPolicy
{

    /**
     * Determine if the given user can view the externaldata.
     *
     * @param UserPolicy $user
     * @param Externaldata $externaldata
     *
     * @return bool
     */
    public function view(UserPolicy $user, Externaldata $externaldata)
    {
        if ($user->canDo('externaldata.externaldata.view') && $user->isAdmin()) {
            return true;
        }

        return $externaldata->user_id == user_id() && $externaldata->user_type == user_type();
    }

    /**
     * Determine if the given user can create a externaldata.
     *
     * @param UserPolicy $user
     * @param Externaldata $externaldata
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('externaldata.externaldata.create');
    }

    /**
     * Determine if the given user can update the given externaldata.
     *
     * @param UserPolicy $user
     * @param Externaldata $externaldata
     *
     * @return bool
     */
    public function update(UserPolicy $user, Externaldata $externaldata)
    {
        if ($user->canDo('externaldata.externaldata.edit') && $user->isAdmin()) {
            return true;
        }

        return $externaldata->user_id == user_id() && $externaldata->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given externaldata.
     *
     * @param UserPolicy $user
     * @param Externaldata $externaldata
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Externaldata $externaldata)
    {
        return $externaldata->user_id == user_id() && $externaldata->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given externaldata.
     *
     * @param UserPolicy $user
     * @param Externaldata $externaldata
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Externaldata $externaldata)
    {
        if ($user->canDo('externaldata.externaldata.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given externaldata.
     *
     * @param UserPolicy $user
     * @param Externaldata $externaldata
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Externaldata $externaldata)
    {
        if ($user->canDo('externaldata.externaldata.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
