<?php

namespace Btravel\Externaldata\Providers;

use Illuminate\Support\ServiceProvider;

class ExternaldataServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'externaldata');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'externaldata');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerExternaldata();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerExternaldata()
    {
        $this->app->bind('externaldata', function($app) {
            return new Externaldata($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Externaldata', 'Lavalite\Externaldata\Facades\Externaldata');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.externaldata', function ($app) {
            return $this->app->make('Btravel\Externaldata\Externaldata');
        });

                // Bind Externaldata to repository
        $this->app->bind(
            'Btravel\Externaldata\Interfaces\ExternaldataRepositoryInterface',
            \Btravel\Externaldata\Repositories\Eloquent\ExternaldataRepository::class
        );

        $this->app->register(\Btravel\Externaldata\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Externaldata\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and externaldata's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'btravel.externaldata'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeExternaldata::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.externaldata'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/externaldata.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/externaldata')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/externaldata')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
